package nl.ivojonker.p8export.excel;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Date;
import java.util.Iterator;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

import com.filenet.api.collection.RepositoryRowSet;
import com.filenet.api.property.Property;
import com.filenet.api.query.RepositoryRow;


/**
 * Allows creation of an xls file filled with the contents of a repositoryRowset.
 * @author ivo jonker(.nl)
 * 
 */
public class Export {
	
	private Export(){}

	public static void writeResults(RepositoryRowSet queryResults, File fileOut) throws IOException {

		if (fileOut.exists()) {
			System.out.println("Deleting old output file..");
			fileOut.delete();
		}
		
		System.out.println("Starting export...");
		HSSFWorkbook workbook = new HSSFWorkbook();
		HSSFSheet sheet = workbook.createSheet("ce-output");
		System.out.print("Writing rows: ");
		
		int rowNum=-1;
		@SuppressWarnings("unchecked")
		Iterator<RepositoryRow> rows = queryResults.iterator();
		while (rows.hasNext()){
			RepositoryRow resultRow = rows.next();
			
			if (rowNum==-1)
				printHeader(sheet.createRow(++rowNum),resultRow);
			
			int cellNum=-1;
			HSSFRow row=sheet.createRow(++rowNum);
			for (Property property : resultRow.getProperties().toArray()){
				setCellValue(row.createCell(++cellNum),property.getObjectValue());
			}
			System.out.print(rowNum+",");
		}
		
		OutputStream fOut = new FileOutputStream(fileOut);
		
		workbook.write(fOut);
		
		workbook.close();
		fOut.close();
	}
	
	private static void printHeader(HSSFRow row, RepositoryRow repositoryRow){
		int cell=-1;
		for (Property property : repositoryRow.getProperties().toArray()){
			setCellValue(row.createCell(++cell),property.getPropertyName());
		}
	}
	
	private static void setCellValue(HSSFCell cell, Object value){
		if (value == null)
			/*nothing*/; 
		else if (value instanceof Boolean)
			cell.setCellValue((Boolean) value);
		else if ( value instanceof Double)
			cell.setCellValue((Double) value);
		else if ( value instanceof Date)
			cell.setCellValue((Date) value);
		else
			cell.setCellValue(value.toString());
	}
	

}
